"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Grid = exports.breakpointSizes = exports.GridVerticalAlignEnum = exports.GridSizeEnum = void 0;
const react_1 = __importDefault(require("react"));
const ramda_1 = require("ramda");
const clsx_1 = __importDefault(require("clsx"));
var GridSizeEnum;
(function (GridSizeEnum) {
    GridSizeEnum["2xl"] = "2xl";
    GridSizeEnum["base"] = "base";
    GridSizeEnum["lg"] = "lg";
    GridSizeEnum["md"] = "md";
    GridSizeEnum["sm"] = "sm";
    GridSizeEnum["xl"] = "xl";
})(GridSizeEnum = exports.GridSizeEnum || (exports.GridSizeEnum = {}));
var GridVerticalAlignEnum;
(function (GridVerticalAlignEnum) {
    GridVerticalAlignEnum["bottom"] = "bottom";
    GridVerticalAlignEnum["center"] = "center";
    GridVerticalAlignEnum["top"] = "top";
})(GridVerticalAlignEnum = exports.GridVerticalAlignEnum || (exports.GridVerticalAlignEnum = {}));
const breakpointSizes = (type) => (0, ramda_1.compose)(ramda_1.values, (0, ramda_1.mapObjIndexed)((size, breakpoint) => {
    if (breakpoint === GridSizeEnum.base) {
        return `${type}-${size}`;
    }
    return `${breakpoint}:${type}-${size}`;
}));
exports.breakpointSizes = breakpointSizes;
const Grid = ({ cols, gap = 1, className, children, vertical }) => {
    return (react_1.default.createElement("div", { className: (0, clsx_1.default)('grid', {
            'grid-cols-1': !(cols === null || cols === void 0 ? void 0 : cols[GridSizeEnum.base]),
        }, className, {
            'grid-items-start': vertical === GridVerticalAlignEnum.top,
            'grid-items-center': vertical === GridVerticalAlignEnum.center,
            'grid-items-end': vertical === GridVerticalAlignEnum.bottom,
        }, (0, exports.breakpointSizes)('grid-cols')(cols !== null && cols !== void 0 ? cols : {}), {
            [`gap-${gap}`]: gap,
        }) }, children));
};
exports.Grid = Grid;
